@@ -5,7 +5,7 @@ OID = ".1.3.6.1.4.1.318.1.1.4.4.2.1.3"
 
 def _snmp_get(host, oid):
     out = processwrapper.check_output(
-        "snmpget -v1 -c private -O qn {} {}".format(host, oid).split()
+        f"snmpget -v1 -c private -O qn {host} {oid}".split()
     ).decode('ascii')
     out_oid, value = out.strip().split(' ', 1)
     assert oid == out_oid
@@ -20,7 +20,7 @@ def _snmp_get(host, oid):
 def _snmp_set(host, oid, value):
     try:
         processwrapper.check_output(
-            "snmpset -v1 -c private {} {} {}".format(host, oid, value).split()
+            f"snmpset -v1 -c private {host} {oid} {value}".split()
         )
     except Exception as e:
         raise ExecutionError("failed to set SNMP value") from e
@@ -33,7 +33,7 @@ def power_set(host, port, index, value):
     value = 1 if value else 2
     assert 1 <= index <= 8
 
-    _snmp_set(host, "{}.{}".format(OID, index), "int {}".format(value))
+    _snmp_set(host, f"{OID}.{index}", f"int {value}")
 
 
 def power_get(host, port, index):
@@ -42,4 +42,4 @@ def power_get(host, port, index):
     index = int(index)
     assert 1 <= index <= 8
 
-    return _snmp_get(host, "{}.{}".format(OID, index))
+    return _snmp_get(host, f"{OID}.{index}")
