@@ -6,6 +6,8 @@ import logging
 import re
 import time
 import shlex
+import ipaddress
+
 import attr
 from pexpect import TIMEOUT
 import xmodem
@@ -13,7 +15,7 @@ import xmodem
 from ..factory import target_factory
 from ..protocol import CommandProtocol, ConsoleProtocol, FileTransferProtocol
 from ..step import step
-from ..util import gen_marker
+from ..util import gen_marker, Timeout
 from .commandmixin import CommandMixin
 from .common import Driver
 from .exception import ExecutionError
@@ -25,6 +27,9 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
     """ShellDriver - Driver to execute commands on the shell
     ShellDriver binds on top of a ConsoleProtocol.
 
+    On activation, the ShellDriver will look for the login prompt on the console,
+    and login to provide shell access.
+
     Args:
         prompt (regex): the shell prompt to detect
         login_prompt (regex): the login prompt to detect
@@ -32,6 +37,13 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
         password (str): password to login with
         keyfile (str): keyfile to bind mount over users authorized keys
         login_timeout (int): optional, timeout for login prompt detection
+        console_ready (regex): optional, pattern used by the kernel to inform the user that a
+            console can be activated by pressing enter.
+        await_login_timeout (int): optional, time in seconds of silence that needs to pass before
+            sending a newline to device.
+        post_login_settle_time (int): optional, seconds of silence after logging in
+            before check for a prompt. Useful when the console is interleaved with boot
+            output which may interrupt prompt detection.
     """
     bindings = {"console": ConsoleProtocol, }
     prompt = attr.ib(validator=attr.validators.instance_of(str))
@@ -42,6 +54,7 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
     login_timeout = attr.ib(default=60, validator=attr.validators.instance_of(int))
     console_ready = attr.ib(default="", validator=attr.validators.instance_of(str))
     await_login_timeout = attr.ib(default=2, validator=attr.validators.instance_of(int))
+    post_login_settle_time = attr.ib(default=0, validator=attr.validators.instance_of(int))
 
 
     def __attrs_post_init__(self):
@@ -49,7 +62,7 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
         self.re_vt100 = re.compile(
             r'(\x1b\[|\x9b)[^@-_a-z]*[@-_a-z]|\x1b[@-_a-z]'
         )  # pylint: disable=attribute-defined-outside-init,anomalous-backslash-in-string
-        self.logger = logging.getLogger("{}:{}".format(self, self.target))
+        self.logger = logging.getLogger(f"{self}:{self.target}")
         self._status = 0  # pylint: disable=attribute-defined-outside-init
 
         self._xmodem_cached_rx_cmd = ""
@@ -84,13 +97,12 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
         self._check_prompt()
         marker = gen_marker()
         # hide marker from expect
-        cmp_command = '''MARKER='{}''{}' run {}'''.format(
-            marker[:4], marker[4:], shlex.quote(cmd)
-        )
+        cmp_command = f'''MARKER='{marker[:4]}''{marker[4:]}' run {shlex.quote(cmd)}'''
         self.console.sendline(cmp_command)
-        _, _, match, _ = self.console.expect(r'{marker}(.*){marker}\s+(\d+)\s+{prompt}'.format(
-            marker=marker, prompt=self.prompt
-        ), timeout=timeout)
+        _, _, match, _ = self.console.expect(
+            rf'{marker}(.*){marker}\s+(\d+)\s+{self.prompt}',
+            timeout=timeout
+        )
         # Remove VT100 Codes, split by newline and remove surrounding newline
         data = self.re_vt100.sub('', match.group(1).decode(codec, decodeerrors)).split('\r\n')
         if data and not data[-1]:
@@ -109,9 +121,9 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
     def _await_login(self):
         """Awaits the login prompt and logs the user in"""
 
-        start = time.time()
+        timeout = Timeout(float(self.login_timeout))
 
-        expectations = [self.prompt, self.login_prompt, TIMEOUT]
+        expectations = [self.prompt, self.login_prompt, "Password: ", TIMEOUT]
         if self.console_ready != "":
             expectations.append(self.console_ready)
 
@@ -121,6 +133,7 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
         # Because pexpect keeps any read data in it's buffer when a timeout
         # occours, we can't lose any data this way.
         last_before = b''
+        did_login = False
 
         while True:
             index, before, _, _ = self.console.expect(
@@ -137,18 +150,15 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
             elif index == 1:
                 # we need to login
                 self.console.sendline(self.username)
-                index, _, _, _ = self.console.expect([self.prompt, "Password: "], timeout=10)
-                if index == 1:
-                    if self.password:
-                        self.console.sendline(self.password)
-                        remaining_time = (start + self.login_timeout) - time.time()
-                        self.console.expect(self.prompt, timeout=remaining_time)
-                    else:
-                        raise Exception("Password entry needed but no password set")
-                self._check_prompt()
-                break
+                did_login = True
 
             elif index == 2:
+                if self.password:
+                    self.console.sendline(self.password)
+                else:
+                    raise Exception("Password entry needed but no password set")
+
+            elif index == 3:
                 # expect hit a timeout while waiting for a match
                 if before == last_before:
                     # we did not receive anything during
@@ -157,7 +167,7 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
                     # newline to check the state
                     self.console.sendline("")
 
-            elif index == 3:
+            elif index == 4:
                 # we have just activated a console here
                 # lets start over again and see if login or prompt will appear
                 # now.
@@ -165,8 +175,13 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
 
             last_before = before
 
-            if time.time() > start + self.login_timeout:
-                raise TIMEOUT("Timeout of {} seconds exceeded during waiting for login".format(self.login_timeout))  # pylint: disable=line-too-long
+            if timeout.expired:
+                raise TIMEOUT(f"Timeout of {self.login_timeout} seconds exceeded during waiting for login")  # pylint: disable=line-too-long
+
+        if did_login:
+            if self.post_login_settle_time > 0:
+                self.console.settle(self.post_login_settle_time, timeout=timeout.remaining)
+            self._check_prompt()
 
     @step()
     def get_status(self):
@@ -181,10 +196,10 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
         """
         marker = gen_marker()
         # hide marker from expect
-        self.console.sendline("echo '{}''{}'".format(marker[:4], marker[4:]))
+        self.console.sendline(f"echo '{marker[:4]}''{marker[4:]}'")
         try:
             self.console.expect(
-                r"{marker}\s+{prompt}".format(marker=marker, prompt=self.prompt),
+                rf"{marker}\s+{self.prompt}",
                 timeout=5
             )
             self._status = 1
@@ -214,8 +229,7 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
                 new_key = match.groupdict()
             else:
                 raise IOError(
-                    "Could not parse SSH-Key from file: {}".
-                    format(keyfile)
+                    f"Could not parse SSH-Key from file: {keyfile}"
                 )
         self.logger.debug("Read Key: %s", new_key)
         auth_keys, _, read_keys = self._run("cat ~/.ssh/authorized_keys")
@@ -240,7 +254,7 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
 
         if test_write == 0 and read_keys == 0:
             self.logger.debug("Key not on target and writeable, concatenating...")
-            self._run_check('echo "{}" >> ~/.ssh/authorized_keys'.format(keyline))
+            self._run_check(f'echo "{keyline}" >> ~/.ssh/authorized_keys')
             self._run_check("rm ~/.test")
             return
 
@@ -252,14 +266,14 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
                 self._run("mkdir ~/.ssh/")
             self._run_check("chmod 700 ~/.ssh/")
             self.logger.debug("Creating ~/.ssh/authorized_keys")
-            self._run_check('echo "{}" > ~/.ssh/authorized_keys'.format(keyline))
+            self._run_check(f'echo "{keyline}" > ~/.ssh/authorized_keys')
             self._run_check("rm ~/.test")
             return
 
         self.logger.debug("Key not on target and not writeable, using bind mount...")
         self._run_check('mkdir -m 700 /tmp/labgrid-ssh/')
         self._run("cp -a ~/.ssh/* /tmp/labgrid-ssh/")
-        self._run_check('echo "{}" >> /tmp/labgrid-ssh/authorized_keys'.format(keyline))
+        self._run_check(f'echo "{keyline}" >> /tmp/labgrid-ssh/authorized_keys')
         self._run_check('chmod 600 /tmp/labgrid-ssh/authorized_keys')
         out, err, exitcode = self._run('mount --bind /tmp/labgrid-ssh/ ~/.ssh/')
         if exitcode != 0:
@@ -298,7 +312,7 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
         """
 
         marker = gen_marker()
-        marked_cmd = "echo '{}''{}'; {}".format(marker[:4], marker[4:], cmd)
+        marked_cmd = f"echo '{marker[:4]}''{marker[4:]}'; {cmd}"
         self.console.sendline(marked_cmd)
         self.console.expect(marker, timeout=30)
 
@@ -341,7 +355,7 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
         # file ourselves.
 
         def _target_cleanup(tmpfile):
-            self._run("rm -f '{}'".format(tmpfile))
+            self._run(f"rm -f '{tmpfile}'")
 
         stream = io.BytesIO(buf)
 
@@ -367,14 +381,13 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
         self.console.expect(self.prompt, timeout=30)
 
         # truncate the file to get rid of CPMEOF padding
-        dd_cmd = "dd if='{}' of='{}' bs=1 count={}".format(tmpfile, remotefile, len(buf))
+        dd_cmd = f"dd if='{tmpfile}' of='{remotefile}' bs=1 count={len(buf)}"
         self.logger.debug('dd command: %s', dd_cmd)
         out, _, ret = self._run(dd_cmd)
 
         _target_cleanup(tmpfile)
         if ret != 0:
-            raise ExecutionError('Could not truncate destination file: dd returned {}: {}'.
-                                 format(ret, out))
+            raise ExecutionError(f'Could not truncate destination file: dd returned {ret}: {out}')
 
     @Driver.check_active
     def put_bytes(self, buf: bytes, remotefile: str):
@@ -419,10 +432,10 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
         self.logger.info('XMODEM send command on target: %s', cmd)
 
         # get file size to remove XMODEM's CPMEOF padding at the end of the last packet
-        out, _, ret = self._run("stat '{}'".format(remotefile))
+        out, _, ret = self._run(f"stat '{remotefile}'")
         match = re.search(r'Size:\s+(?P<size>\d+)', '\n'.join(out))
         if ret != 0 or not match or not match.group("size"):
-            raise ExecutionError("Could not stat '{}' on target".format(remotefile))
+            raise ExecutionError(f"Could not stat '{remotefile}' on target")
 
         file_size = int(match.group('size'))
         self.logger.debug('file size on target is %d', file_size)
@@ -435,8 +448,7 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
 
         # remove CPMEOF (0x1a) padding
         if recvd_size < file_size:
-            raise ExecutionError('Only received {} bytes of {} expected'.
-                                 format(recvd_size, file_size))
+            raise ExecutionError(f'Only received {recvd_size} bytes of {file_size} expected')
 
         self.logger.debug('received %d bytes of payload', file_size)
         buf.truncate(file_size)
@@ -487,7 +499,7 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
     def _run_script(self, data: bytes, timeout: int = 60):
         hardcoded_remote_file = '/tmp/labgrid-run-script'
         self._put_bytes(data, hardcoded_remote_file)
-        self._run_check("chmod +x '{}'".format(hardcoded_remote_file))
+        self._run_check(f"chmod +x '{hardcoded_remote_file}'")
         return self._run(hardcoded_remote_file, timeout=timeout)
 
     @Driver.check_active
@@ -510,10 +522,10 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
     def _run_script_file(self, scriptfile: str, *args, timeout: int = 60):
         hardcoded_remote_file = '/tmp/labgrid-run-script'
         self._put(scriptfile, hardcoded_remote_file)
-        self._run_check("chmod +x '{}'".format(hardcoded_remote_file))
+        self._run_check(f"chmod +x '{hardcoded_remote_file}'")
 
         shargs = [shlex.quote(a) for a in args]
-        cmd = "{} {}".format(hardcoded_remote_file, ' '.join(shargs))
+        cmd = f"{hardcoded_remote_file} {' '.join(shargs)}"
         return self._run(cmd, timeout=timeout)
 
     @Driver.check_active
@@ -533,3 +545,58 @@ class ShellDriver(CommandMixin, Driver, CommandProtocol, FileTransferProtocol):
             IOError: if the provided localfile could not be found
         """
         return self._run_script_file(scriptfile, *args, timeout=timeout)
+
+    @Driver.check_active
+    def get_default_interface_device_name(self, version=4):
+        """ Retrieve the default route's interface device name.
+
+        Args:
+            version (int): IP version
+
+        Returns:
+            Name of the device of the default route
+
+        Raises:
+            ExecutionError: if no or multiple routes are set up
+        """
+        assert version in (4, 6)
+
+        regex = r"""default\s+via # leading strings
+                \s+\S+ # IP address
+                \s+dev\s+(\w+) # interface"""
+
+        default_route = self._run_check(f"ip -{version} route list default")
+        matches = re.findall(regex, "\n".join(default_route), re.X)
+
+        if not matches:
+            raise ExecutionError(f"No IPv{version} default route found")
+        if len(matches) > 1:
+            raise ExecutionError(f"Multiple IPv{version} default routes found")
+
+        return matches[0]
+
+    @Driver.check_active
+    def get_ip_addresses(self, device=None):
+        """ Retrieves IP addresses for given interface name.
+
+        Note that although the return type is named IPv4Interface/IPv6Interface, it contains an IP
+        address with the corresponding network prefix.
+
+        Args:
+            device (str): Name of the interface to query, defaults to default route's device name.
+
+        Returns:
+            List of IPv4Interface or IPv6Interface objects
+        """
+        if device is None:
+            device = self.get_default_interface_device_name()
+
+        regex = r"""\d+: # leading number
+                \s+\w+ # interface name
+                \s+inet6?\s+(\S+) # IP address, prefix
+                .*global # global scope, not host scope"""
+
+        ip_show = self._run_check(f"ip -o addr show dev {device}")
+        matches = re.findall(regex, "\n".join(ip_show), re.X)
+
+        return list(map(ipaddress.ip_interface, matches))
