@@ -1,4 +1,6 @@
 # pylint: disable=no-member
+import subprocess
+
 import attr
 
 from .common import Driver
@@ -32,11 +34,25 @@ class USBSDMuxDriver(Driver):
     @step(title='sdmux_set', args=['mode'])
     def set_mode(self, mode):
         if not mode.lower() in ['dut', 'host', 'off', 'client']:
-            raise ExecutionError("Setting mode '%s' not supported by USBSDMuxDriver" % mode)
+            raise ExecutionError(f"Setting mode '{mode}' not supported by USBSDMuxDriver")
         cmd = self.mux.command_prefix + [
             self.tool,
-            "-c",
             self.mux.control_path,
             mode.lower()
         ]
         processwrapper.check_output(cmd)
+
+    @Driver.check_active
+    @step(title='sdmux_get')
+    def get_mode(self):
+        cmd = self.mux.command_prefix + [
+            self.tool,
+            self.mux.control_path,
+            "get"
+        ]
+        proc = subprocess.run(
+            cmd,
+            stdout=subprocess.PIPE,
+            check=True
+        )
+        return proc.stdout.strip().decode()
