@@ -1116,7 +1116,7 @@ class ClientSession(ApplicationSession):
                 print(f"Forwarding local port {localport:d} to remote port {remote:d}")
 
             for local, remote in self.args.remote:
-                stack.enter_context(drv.forward_remote_port(remote, localport))
+                stack.enter_context(drv.forward_remote_port(remote, local))
                 print(f"Forwarding remote port {remote:d} to local port {local:d}")
 
             try:
@@ -1852,7 +1852,7 @@ def main():
                 print(f"{parser.prog}: error: {e}", file=sys.stderr)
             exitcode = 1
         except KeyboardInterrupt:
-            exitcode = 0
+            exitcode = 1
         except Exception:  # pylint: disable=broad-except
             traceback.print_exc()
             exitcode = 2
