@@ -1,4 +1,4 @@
-from .base import SerialPort, EthernetInterface, EthernetPort
+from .base import SerialPort, NetworkInterface, EthernetPort
 from .ethernetport import SNMPEthernetPort
 from .serialport import RawSerialPort, NetworkSerialPort
 from .modbus import ModbusTCPCoil
@@ -18,3 +18,6 @@ from .flashrom import Flashrom, NetworkFlashrom
 from .docker import DockerManager, DockerDaemon, DockerConstants
 from .lxaiobus import LXAIOBusPIO
 from .pyvisa import PyVISADevice
+from .provider import TFTPProvider
+from .mqtt import TasmotaPowerPort
+from .httpvideostream import HTTPVideoStream
