@@ -10,7 +10,7 @@ import pyudev
 
 from ..factory import target_factory
 from .common import ManagedResource, ResourceManager
-from .base import SerialPort, EthernetInterface
+from .base import SerialPort, NetworkInterface
 from ..util import Timeout
 
 
@@ -32,7 +32,7 @@ class UdevManager(ResourceManager):
         devices.match_subsystem(resource.match['SUBSYSTEM'])
         for device in devices:
             if resource.try_match(device):
-                break
+                self.log.debug(" matched successfully against %s", resource.device)
 
     def _insert_into_queue(self, device):
         self.queue.put(device)
@@ -46,9 +46,8 @@ class UdevManager(ResourceManager):
                 break
             self.log.debug("%s: %s", device.action, device)
             for resource in self.resources:
-                self.log.debug(" %s", resource)
                 if resource.try_match(device):
-                    break
+                    self.log.debug(" matched successfully")
 
 @attr.s(eq=False)
 class USBResource(ManagedResource):
@@ -144,7 +143,7 @@ class USBResource(ManagedResource):
 
         if device.action in [None, 'add']:
             if self.avail:
-                warnings.warn("udev device {} is already available".format(device))
+                warnings.warn(f"udev device {device} is already available")
             self.device = device
         elif device.action in ['change', 'move']:
             self.device = device
@@ -278,7 +277,11 @@ class IMXUSBLoader(USBResource):
                          ("15a2", "007d"), ("15a2", "0076"),
                          ("15a2", "0080"), ("15a2", "003a"),
                          ("1fc9", "0128"), ("1fc9", "0126"),
-                         ("1fc9", "012b"), ("1fc9", "0134")]:
+                         ("1fc9", "012b"), ("1fc9", "0134"),
+                         ("1fc9", "013e"), ("1fc9", "0146"),
+                         ("1b67", "4fff"), ("0525", "b4a4"), # SPL
+                         ("3016", "1001"),
+                         ]:
             return False
 
         return super().filter_match(device)
@@ -319,7 +322,7 @@ class AndroidFastboot(USBResource):
 
 @target_factory.reg_resource
 @attr.s(eq=False)
-class USBEthernetInterface(USBResource, EthernetInterface):
+class USBNetworkInterface(USBResource, NetworkInterface):
     def __attrs_post_init__(self):
         self.match['SUBSYSTEM'] = 'net'
         self.match['@SUBSYSTEM'] = 'usb'
@@ -553,6 +556,41 @@ class USBVideo(USBResource):
 
         return None
 
+@target_factory.reg_resource
+@attr.s(eq=False)
+class USBAudioInput(USBResource):
+    # the ALSA PCM device number (as in hw:CARD=<card>,DEV=<index>)
+    index = attr.ib(default=0, validator=attr.validators.instance_of(int))
+
+    def filter_match(self, device):
+        suffix = f"D{self.index}c"
+
+        if not device.sys_name.endswith(suffix):
+            return False
+
+        return super().filter_match(device)
+
+    def __attrs_post_init__(self):
+        self.match['SUBSYSTEM'] = 'sound'
+        self.match['@SUBSYSTEM'] = 'usb'
+        super().__attrs_post_init__()
+
+    @property
+    def path(self):
+        "the device node (for example /dev/snd/pcmC3D0c)"
+        if self.device is not None:
+            return self.device.device_node
+
+        return None
+
+    @property
+    def alsa_name(self):
+        "the ALSA device name (for example hw:CARD=3,DEV=0)"
+        if self.device is not None:
+            return f"hw:CARD={self.device.parent.attributes.asint('number')},DEV={self.index}"
+
+        return None
+
 @target_factory.reg_resource
 @attr.s(eq=False)
 class USBTMC(USBResource):
@@ -581,9 +619,47 @@ class DeditecRelais8(USBResource):
         self.match['ID_MODEL'] = 'DEDITEC_USB-OPT_REL-8'
         super().__attrs_post_init__()
 
-    @property
-    def path(self):
-        if self.device is not None:
-            return self.device.device_path
 
+@target_factory.reg_resource
+@attr.s(eq=False)
+class HIDRelay(USBResource):
+    index = attr.ib(default=1, validator=attr.validators.instance_of(int))
+    invert = attr.ib(default=False, validator=attr.validators.instance_of(bool))
+
+    def __attrs_post_init__(self):
+        self.match['ID_VENDOR_ID'] = '16c0'
+        self.match['ID_MODEL_ID'] = '05df'
+        super().__attrs_post_init__()
+
+@target_factory.reg_resource
+@attr.s(eq=False)
+class USBFlashableDevice(USBResource):
+    @property
+    def devnode(self):
+        if self.device is not None:
+            return self.device.device_node
         return None
+
+@target_factory.reg_resource
+@attr.s(eq=False)
+class LXAUSBMux(USBResource):
+    """The LXAUSBMux describes an attached USBMux device,
+    it is identified via USB using udev.
+    """
+
+    def __attrs_post_init__(self):
+        self.match['ID_VENDOR_ID'] = '33f7'
+        self.match['ID_MODEL_ID'] = '0001'
+        super().__attrs_post_init__()
+
+@target_factory.reg_resource
+@attr.s(eq=False)
+class USBDebugger(USBResource):
+    def filter_match(self, device):
+        match = (device.properties.get('ID_VENDOR_ID'), device.properties.get('ID_MODEL_ID'))
+
+        if match not in [("0403", "6010"),
+                         ]:
+            return False
+
+        return super().filter_match(device)
