@@ -2,7 +2,6 @@ import abc
 import atexit
 import logging
 from time import monotonic, sleep
-from collections import Counter
 
 import attr
 
@@ -21,7 +20,7 @@ class Target:
     env = attr.ib(default=None)
 
     def __attrs_post_init__(self):
-        self.log = logging.getLogger("target({})".format(self.name))
+        self.log = logging.getLogger(f"target({self.name})")
         self.resources = []
         self.drivers = []
         self.last_update = 0.0
@@ -37,7 +36,7 @@ class Target:
 
     def interact(self, msg):
         if self.env:
-            self.env.interact("{}: {}".format(self.name, msg))
+            self.env.interact(f"{self.name}: {msg}")
         else:
             input(msg)
 
@@ -69,8 +68,9 @@ class Target:
         waiting = set(r for r in resources if r.avail != avail)
         static = set(r for r in waiting if r.get_managed_parent() is None)
         if static:
-            raise NoResourceFoundError("Static resources are not {}: {}".format(
-                "available" if avail else "unavailable", static))
+            raise NoResourceFoundError(
+                f"Static resources are not {'available' if avail else 'unavailable'}: {static}"
+            )
 
         if not waiting:
             return
@@ -90,8 +90,7 @@ class Target:
 
         if waiting:
             raise NoResourceFoundError(
-                "Not all resources are {}: {}".format(
-                    "available" if avail else "unavailable", waiting),
+                f"Not all resources are {'available' if avail else 'unavailable'}: {waiting}",
                 filter=waiting
             )
 
@@ -121,20 +120,18 @@ class Target:
                 continue
             found.append(res)
         if not found:
-            name_msg = " named '{}'".format(name) if name else ""
+            name_msg = f" named '{name}'" if name else ""
             if other_names:
                 raise NoResourceFoundError(
-                    "no {cls} resource{name} found in {target}, matching resources with other names: {other_names}".format(  # pylint: disable=line-too-long
-                        cls=cls, name=name_msg, target=self, other_names=other_names)
+                    f"no {cls} resource{name_msg} found in {self}, matching resources with other names: {other_names}"  # pylint: disable=line-too-long
                 )
 
             raise NoResourceFoundError(
-                "no {cls} resource{name} found in {target}".format(
-                    cls=cls, name=name_msg, target=self)
+                f"no {cls} resource{name_msg} found in {self}"
             )
         elif len(found) > 1:
             raise NoResourceFoundError(
-                "multiple resources matching {cls} found in {target}".format(cls=cls, target=self)
+                f"multiple resources matching {cls} found in {self}"
             )
         if wait_avail:
             self.await_resources(found)
@@ -158,7 +155,7 @@ class Target:
                 continue
             found.append(drv)
         if not found:
-            name_msg = " named '{}'".format(name) if name else ""
+            name_msg = f" named '{name}'" if name else ""
             if other_names:
                 raise NoDriverFoundError(
                     "no {active}{cls} driver{name} found in {target}, matching resources with other names: {other_names}".format(  # pylint: disable=line-too-long
@@ -167,9 +164,7 @@ class Target:
                 )
 
             raise NoDriverFoundError(
-                "no {active}{cls} driver{name} found in {target}".format(
-                    active="active " if active else "", cls=cls, name=name_msg, target=self
-                )
+                f"no {'active ' if active else ''}{cls} driver{name_msg} found in {self}"
             )
         elif len(found) > 1:
             prio_last = -255
@@ -239,7 +234,7 @@ class Target:
             cls = target_factory.class_from_string(cls)
         if not issubclass(cls, (Driver, abc.ABC)): # all Protocols derive from ABC
             raise NoDriverFoundError(
-                "invalid driver class {}".format(cls)
+                f"invalid driver class {cls}"
             )
 
         return self.get_active_driver(cls, name=name)
@@ -256,7 +251,7 @@ class Target:
         """
         if resource.state is not BindingState.idle:
             raise BindingError(
-                "{} is not in state {}".format(resource, BindingState.idle)
+                f"{resource} is not in state {BindingState.idle}"
             )
 
         # consistency check
@@ -280,7 +275,7 @@ class Target:
         """
         if client.state is not BindingState.idle:
             raise BindingError(
-                "{} is not in state {}".format(client, BindingState.idle)
+                f"{client} is not in state {BindingState.idle}"
             )
 
         # consistency check
@@ -293,6 +288,7 @@ class Target:
 
         # locate suppliers
         bound_suppliers = []
+        bound_req_pairs = set()
         for name, requirements in client.bindings.items():
             explicit = False
             if isinstance(requirements, Driver.NamedBinding):
@@ -301,8 +297,7 @@ class Target:
             supplier_name = mapping.pop(name, None)
             if explicit and supplier_name is None:
                 raise BindingError(
-                    "supplier for {name} ({requirements}) of {driver} in {target} requires an explicit name".format(  # pylint: disable=line-too-long
-                        name=name, requirements=requirements, driver=client, target=self)
+                    f"supplier for {name} ({requirements}) of {client} in {self} requires an explicit name"  # pylint: disable=line-too-long
                 )
             # use sets even for a single requirement and make a local copy
             if not isinstance(requirements, set):
@@ -329,7 +324,7 @@ class Target:
                             self.get_driver(requirement, name=supplier_name, activate=False),
                         )
                     else:
-                        raise NoSupplierFoundError("invalid binding type {}".format(requirement))
+                        raise NoSupplierFoundError(f"invalid binding type {requirement}")
                 except NoSupplierFoundError as e:
                     errors.append(e)
             if not suppliers:
@@ -339,13 +334,17 @@ class Target:
                     raise errors[0]
                 else:
                     raise NoSupplierFoundError(
-                        "no supplier matching {requirements} found in {target} (errors: {errors})".format(  # pylint: disable=line-too-long
-                            requirements=requirements, target=self, errors=errors)
+                        f"no supplier matching {requirements} found in {self} (errors: {errors})"
                     )
             elif len(suppliers) > 1:
-                raise NoSupplierFoundError("conflicting suppliers matching {} found in target {}".format(requirements, self))  # pylint: disable=line-too-long
+                raise NoSupplierFoundError(f"conflicting suppliers matching {requirements} found in target {self}")  # pylint: disable=line-too-long
             else:
                 supplier = suppliers[0]
+            if supplier is not None and (requirement, supplier) in bound_req_pairs:
+                raise BindingError(
+                    f"duplicate bindings of {supplier} to {name} for {requirement} found in target {self}"  # pylint: disable=line-too-long
+                )
+            bound_req_pairs.add((requirement, supplier))
             setattr(client, name, supplier)
             if supplier is not None:
                 bound_suppliers.append(supplier)
@@ -356,16 +355,10 @@ class Target:
             assert client not in supplier.clients
             assert supplier not in client.suppliers
 
-        duplicates = {k for k, c in Counter(bound_suppliers).items() if c > 1}
-        if duplicates:
-            raise BindingError(
-                "duplicate bindings {} found in target {}".format(duplicates, self)
-            )
-
         # make sure drivers consume all given bindings
         if mapping and not isinstance(client, Strategy):
             raise BindingError(
-                "{} got unexpected bindings: {}".format(client, list(mapping.keys()))
+                f"{client} got unexpected bindings: {list(mapping.keys())}"
             )
 
         # update relationship in both directions
@@ -391,7 +384,7 @@ class Target:
         if isinstance(bindable, Driver):
             return self.bind_driver(bindable)
 
-        raise BindingError("object {} is not bindable".format(bindable))
+        raise BindingError(f"object {bindable} is not bindable")
 
     def activate(self, client, name=None):
         """
@@ -413,7 +406,7 @@ class Target:
 
         if client.state is not BindingState.bound:
             raise BindingError(
-                "{} is not in state {}".format(client, BindingState.bound)
+                f"{client} is not in state {BindingState.bound}"
             )
 
         # consistency check
@@ -450,7 +443,7 @@ class Target:
 
         if client.state is not BindingState.active:
             raise BindingError(
-                "{} is not in state {}".format(client, BindingState.active)
+                f"{client} is not in state {BindingState.active}"
             )
 
         # consistency check
@@ -474,7 +467,7 @@ class Target:
         except Exception as e:
             print("An exception occured during cleanup, call the cleanup() "
                   "method on targets yourself to handle exceptions explictly.")
-            print("Error: {}", e)
+            print(f"Error: {e}")
 
     def cleanup(self):
         """Clean up conntected drivers and resources in reversed order"""
