@@ -7,6 +7,7 @@ import subprocess
 import os
 from select import select
 from functools import wraps
+from typing import Dict
 
 import attr
 from ..driver.exception import ExecutionError
@@ -22,14 +23,14 @@ class SSHConnectionManager:
     should not be directly instantiated, use the exported sshmanager from this
     module instead.
     """
-    _connections = attr.ib(
+    _connections: 'Dict[str, SSHConnection]' = attr.ib(
         default=attr.Factory(dict),
         init=False,
         validator=attr.validators.optional(attr.validators.instance_of(dict))
     )
 
     def __attrs_post_init__(self):
-        self.logger = logging.getLogger("{}".format(self))
+        self.logger = logging.getLogger(f"{self}")
         atexit.register(self.close_all)
 
     def get(self, host: str):
@@ -107,6 +108,20 @@ class SSHConnectionManager:
             self.remove_by_name(name)
 
 
+def _check_connected(func):
+    """Check if an SSHConnection is connected as a decorator"""
+
+    @wraps(func)
+    def wrapper(self, *_args, **_kwargs):
+        if not self.isconnected():
+            raise ExecutionError(
+                f"{func.__qualname__} can not be called ({self} is not connected)"
+            )
+        return func(self, *_args, **_kwargs)  # pylint: disable=not-callable
+
+    return wrapper
+
+
 @attr.s
 class SSHConnection:
     """SSHConnections are individual connections to hosts managed by a control
@@ -128,7 +143,7 @@ class SSHConnection:
     _forwards = attr.ib(init=False, default=attr.Factory(dict))
 
     def __attrs_post_init__(self):
-        self._logger = logging.getLogger("{}".format(self))
+        self._logger = logging.getLogger(f"{self}")
         self._socket = None
         self._master = None
         self._keepalive = None
@@ -142,7 +157,7 @@ class SSHConnection:
         if self._socket:
             return [
                 "-o", "ControlMaster=no",
-                "-o", "ControlPath={}".format(self._socket),
+                "-o", f"ControlPath={self._socket}",
             ]
         return []
 
@@ -179,21 +194,6 @@ class SSHConnection:
             timeout=2,
         )
 
-    def _check_connected(func):  # pylint: disable=no-self-argument
-        """Check if an SSHConnection is connected as a decorator"""
-
-        @wraps(func)
-        def wrapper(self, *_args, **_kwargs):
-            if not self.isconnected():
-                raise ExecutionError(
-                    "{} can not be called ({} is not connected)".format(
-                        func.__qualname__, self
-                    )
-                )
-            return func(self, *_args, **_kwargs)  # pylint: disable=not-callable
-
-        return wrapper
-
     @_check_connected
     def get_prefix(self):
         return ["ssh"] + self._get_ssh_args() + [self.host]
@@ -239,7 +239,7 @@ class SSHConnection:
             )
         except:
             raise ExecutionError(
-                "error executing command: {}".format(complete_cmd)
+                f"error executing command: {complete_cmd}"
             )
 
         stdout = []
@@ -310,8 +310,8 @@ class SSHConnection:
         """Get a file from the remote host"""
         complete_cmd = ["scp"] + self._get_ssh_control_args()
         complete_cmd += [
-            "{}:{}".format(self.host, remote_file),
-            "{}".format(local_file)
+            f"{self.host}:{remote_file}",
+            f"{local_file}"
         ]
         self._logger.debug("Running command: %s", complete_cmd)
         subprocess.check_call(
@@ -325,8 +325,8 @@ class SSHConnection:
         complete_cmd = ["rsync", "--compress=1", "--sparse", "--copy-links", "--verbose", "--progress", "--times", "-e",
                         " ".join(['ssh'] + self._get_ssh_args())]
         complete_cmd += [
-            "{}".format(local_file),
-            "{}:{}".format(self.host, remote_path)
+            f"{local_file}",
+            f"{self.host}:{remote_path}"
         ]
         self._logger.debug("Running command: %s", complete_cmd)
         subprocess.check_call(
@@ -338,16 +338,14 @@ class SSHConnection:
     def add_port_forward(self, remote_host, remote_port):
         """forward command"""
         local_port = get_free_port()
-        destination = "{}:{}".format(remote_host, remote_port)
+        destination = f"{remote_host}:{remote_port}"
 
         # pylint: disable=not-an-iterable
         if destination in self._forwards:
             return self._forwards[destination]
         self._run_socket_command(
             "forward", [
-                "-L"
-                "{local}:{destination}".
-                format(local=local_port, destination=destination)
+                f"-L{local_port}:{destination}"
             ]
         )
         self._forwards[destination] = local_port
@@ -356,7 +354,7 @@ class SSHConnection:
     @_check_connected
     def remove_port_forward(self, remote_host, remote_port):
         """cancel command"""
-        destination = "{}:{}".format(remote_host, remote_port)
+        destination = f"{remote_host}:{remote_port}"
         local_port = self._forwards.pop(destination, None)
 
         # pylint: disable=not-an-iterable
@@ -365,9 +363,7 @@ class SSHConnection:
 
         self._run_socket_command(
             "cancel", [
-                "-L"
-                "{local}:localhost:{remote}".
-                format(local=local_port, remote=remote_port)
+                f"-L{local_port}:localhost:{remote_port}"
             ]
         )
 
@@ -379,7 +375,7 @@ class SSHConnection:
         return self._connected and self._check_keepalive()
 
     def _check_external_master(self):
-        args = ["ssh", "-O", "check", "{}".format(self.host)]
+        args = ["ssh", "-O", "check", f"{self.host}"]
         # We don't want to confuse the use with SSHs output here, so we need to
         # capture and parse it.
         proc = subprocess.Popen(
@@ -393,7 +389,7 @@ class SSHConnection:
         if check == 0:
             self._logger.debug("Found existing control socket")
             return True
-        if b"No such file or directory" or b"No ControlPath specified" in stdout:
+        if b"No such file or directory" in stdout or b"No ControlPath specified" in stdout:
             self._logger.debug("No existing control socket found")
             return False
 
@@ -402,7 +398,7 @@ class SSHConnection:
 
     def _start_own_master(self):
         """Starts a controlmaster connection in a temporary directory."""
-        control = os.path.join(self._tmpdir, 'control-{}'.format(self.host))
+        control = os.path.join(self._tmpdir, f'control-{self.host}')
 
         self._logger.debug("ControlSocket: %s", control)
         args = ["ssh"] + SSHConnection._get_ssh_base_args()
@@ -411,7 +407,7 @@ class SSHConnection:
             "-o", "ConnectTimeout=30",
             "-o", "ControlPersist=300",
             "-o", "ControlMaster=yes",
-            "-o", "ControlPath={}".format(control),
+            "-o", f"ControlPath={control}",
             # We don't want to ask the user to confirm host keys here.
             "-o", "StrictHostKeyChecking=yes",
             self.host,
@@ -429,22 +425,15 @@ class SSHConnection:
         try:
             if self._master.wait(timeout=30) != 0:
                 raise ExecutionError(
-                    "failed to connect to {} with args {}, returncode={} {},{} ".format(
-                        self.host, args, self._master.wait(),
-                        self._master.stdout.readlines(),
-                        self._master.stderr.readlines()
-                    )
+                    f"failed to connect to {self.host} with args {args}, returncode={self._master.wait()} {self._master.stdout.readlines()},{self._master.stderr.readlines()} "  # pylint: disable=line-too-long
                 )
         except subprocess.TimeoutExpired:
             raise ExecutionError(
-                "failed to connect (timeout) to {} with args {} {},{}".format(
-                    self.host, args, self._master.stdout.readlines(),
-                    self._master.stderr.readlines()
-                )
+                f"failed to connect (timeout) to {self.host} with args {args} {self._master.stdout.readlines()},{self._master.stderr.readlines()}"  # pylint: disable=line-too-long
             )
 
         if not os.path.exists(control):
-            raise ExecutionError("no control socket to {}".format(self.host))
+            raise ExecutionError(f"no control socket to {self.host}")
 
         self._socket = control
 
