@@ -1,6 +1,7 @@
 import os.path
 import subprocess
 import socket
+import atexit
 
 from shutil import which
 
@@ -184,6 +185,9 @@ def test_sshconnection_cleanup(connection_localhost_no_cleanup):
 
     connection_localhost_no_cleanup.cleanup()
 
+    # do not call cleanup() again on termination
+    atexit.unregister(connection_localhost_no_cleanup.cleanup)
+
 @pytest.mark.localsshmanager
 def test_sshmanager_open(sshmanager_fix):
     con = sshmanager_fix.open("localhost")
@@ -217,6 +221,7 @@ def test_sshmanager_remove_raise(sshmanager_fix):
     with pytest.raises(ExecutionError):
         sshmanager_fix.remove_connection(con)
 
+@pytest.mark.skipif(not which("ssh"), reason="ssh not available")
 def test_sshmanager_add_duplicate(sshmanager_fix):
     host = 'localhost'
     con = SSHConnection(host)
@@ -227,6 +232,7 @@ def test_sshmanager_add_duplicate(sshmanager_fix):
 
     assert con_now == con_there
 
+@pytest.mark.skipif(not which("ssh"), reason="ssh not available")
 def test_sshmanager_add_new(sshmanager_fix):
     host = 'other_host'
     con = SSHConnection(host)
@@ -235,6 +241,7 @@ def test_sshmanager_add_new(sshmanager_fix):
 
     assert con_now == con
 
+@pytest.mark.skipif(not which("ssh"), reason="ssh not available")
 def test_sshmanager_invalid_host_raise():
     con = SSHConnection("nosuchhost.notavailable")
     with pytest.raises(ExecutionError):
@@ -289,9 +296,9 @@ Test
     mf = ManagedFile(t, res, detect_nfs=False)
     mf.sync_to_resource()
 
-    assert os.path.isfile("/var/cache/labgrid/{}/{}/test".format(getpass.getuser(), hash))
+    assert os.path.isfile(f"/var/cache/labgrid/{getpass.getuser()}/{hash}/test")
     assert hash == mf.get_hash()
-    assert "/var/cache/labgrid/{}/{}/test".format(getpass.getuser(), hash) == mf.get_remote_path()
+    assert f"/var/cache/labgrid/{getpass.getuser()}/{hash}/test" == mf.get_remote_path()
 
 @pytest.mark.localsshmanager
 def test_remote_managedfile_on_nfs(target, tmpdir):
